lavalink_rs.model.search API documentation

# lavalink_rs.model.search

class SearchEngines:
def youtube(query: str) -> str:
def youtube_music(query: str) -> str:
def soundcloud(query: str) -> str:
def spotify(query: str) -> str:
def spotify_recommended( query: str, parameters: lavalink_rs.model.search.SpotifyRecommendedParameters) -> str:
def apple_music(query: str) -> str:
def deezer(query: str) -> str:
def deezer_isrc(query: str) -> str:
def yandex_music(query: str) -> str:
def flowery_tts( query: str, parameters: lavalink_rs.model.search.FloweryTTSParameters) -> str:
class SpotifyRecommendedParameters:

Any of the seed fields must have a value.

Spotify documentation can be found here

max_tempo: int
max_energy: float
target_popularity: int
min_popularity: int
target_time_signature: float
max_valence: float
limit: int
max_acousticness: float
min_duration_ms: int
seed_tracks: str
seed_artists: str
max_key: float
min_instrumentalness: float
target_energy: float
max_danceability: float
target_mode: float
target_speechiness: float
max_time_signature: float
seed_genres: str
target_valence: float
min_loudness: int
min_energy: float
min_acousticness: float
target_loudness: int
target_danceability: float
target_instrumentalness: float
min_danceability: float
max_mode: float
target_acousticness: float
min_time_signature: float
min_key: float
target_tempo: int
min_valence: float
min_liveness: float
max_popularity: int
max_liveness: float
target_liveness: float
max_instrumentalness: float
market: str
max_duration_ms: int
max_loudness: int
min_speechiness: float
target_duration_ms: int
target_key: float
min_tempo: int
min_mode: float
max_speechiness: float
class FloweryTTSParameters:
voice: str

A list of voices can be found here

audio_format: str

Supported formats are: mp3, ogg_opus, ogg_vorbis, aac, wav, and flac.

translate: bool

TODO: Document this.

silence: int

The silence parameter is in milliseconds. Range is 0 to 10000. The default is 0.

speed: float

The speed parameter is a float between 0.5 and 10. The default is 1.0. (0.5 is half speed, 2.0 is double speed, etc.)